@@ -1,7 +1,7 @@
 package Net::RackSpace::CloudServers;
 
 BEGIN {
-    $Net::RackSpace::CloudServers::VERSION = '0.12_02';
+    $Net::RackSpace::CloudServers::VERSION = '0.10';
 }
 use warnings;
 use strict;
@@ -14,7 +14,7 @@ use LWP::ConnCache::MaxKeepAliveRequests;
 use LWP::UserAgent::Determined;
 use JSON;
 use YAML;
-use Carp;
+use 5.010_000;
 
 our $DEBUG = 0;
 
@@ -84,8 +84,7 @@ sub _authenticate {
     );
     my $response = $self->_request($request);
     confess 'Unauthorized' if $response->code == 401;
-    confess 'Unknown error ' . $response->code . "\n" . $response->content
-      if $response->code != 204;
+    confess 'Unknown error ' . $response->code if $response->code != 204;
 
     my $server_management_url = $response->header('X-Server-Management-Url')
       || confess 'Missing server management url';
@@ -167,9 +166,8 @@ sub get_server {
         [ 'X-Auth-Token' => $self->token ]
     );
     my $response = $self->_request($request);
-    return if scalar grep { $response->code eq $_ } ( 204, 404 );
-    confess 'Unknown error' . $response->code
-      unless scalar grep { $response->code eq $_ } ( 200, 203 );
+    return if $response->code ~~ [ 204, 404 ];
+    confess 'Unknown error' . $response->code unless ( $response->code ~~ [ 200, 203 ] );
     my @servers;
     my $hash_response = from_json( $response->content );
     warn Dump($hash_response) if $DEBUG;
@@ -242,8 +240,7 @@ sub get_flavor {
     );
     my $response = $self->_request($request);
     return if $response->code == 204;
-    confess 'Unknown error ' . $response->code
-      unless scalar grep { $response->code eq $_ } ( 200, 203 );
+    confess 'Unknown error ' . $response->code unless ( $response->code ~~ [ 200, 203 ] );
     my $hash_response = from_json( $response->content );
     warn Dump($hash_response) if $DEBUG;
 
@@ -297,8 +294,7 @@ sub get_image {
     );
     my $response = $self->_request($request);
     return if $response->code == 204;
-    confess 'Unknown error' . $response->code
-      unless scalar grep { $response->code eq $_ } ( 200, 203 );
+    confess 'Unknown error ' . $response->code unless ( $response->code ~~ [ 200, 203 ] );
     my $hash_response = from_json( $response->content );
     warn Dump($hash_response) if $DEBUG;
 
@@ -353,8 +349,7 @@ sub delete_image {
         ],
     );
     my $response = $self->_request($request);
-    confess 'Unknown error' . $response->code
-      unless scalar grep { $response->code eq $_ } ( 200, 204 );
+    confess 'Unknown error ' . $response->code unless ( $response->code ~~ [ 202, 204 ] );
     return;
 }
 
@@ -364,7 +359,7 @@ Net::RackSpace::CloudServers - Interface to RackSpace CloudServers via API
 
 =head1 VERSION
 
-version 0.12_02
+version 0.10
 
 =head1 SYNOPSIS
 
