@@ -1,12 +1,11 @@
 package Net::RackSpace::CloudServers::Flavor;
 
 BEGIN {
-    $Net::RackSpace::CloudServers::Flavor::VERSION = '0.12_02';
+    $Net::RackSpace::CloudServers::Flavor::VERSION = '0.10';
 }
 use warnings;
 use strict;
 use Any::Moose;
-use Carp;
 
 has 'cloudservers' => ( is => 'rw', isa => 'Net::RackSpace::CloudServers', required => 1 );
 has 'id'           => ( is => 'ro', isa => 'Int',                          required => 1 );
@@ -23,7 +22,7 @@ Net::RackSpace::CloudServers::Flavor - a RackSpace CloudServers Flavor
 
 =head1 VERSION
 
-version 0.12_02
+version 0.10
 
 =head1 SYNOPSIS
 
