@@ -1,7 +1,7 @@
 package Net::RackSpace::CloudServers::Limits;
 
 BEGIN {
-    $Net::RackSpace::CloudServers::Limits::VERSION = '0.12_02';
+    $Net::RackSpace::CloudServers::Limits::VERSION = '0.10';
 }
 use warnings;
 use strict;
@@ -10,7 +10,6 @@ use Any::Moose;
 use HTTP::Request;
 use JSON;
 use YAML;
-use Carp;
 
 has 'cloudservers' => ( is => 'rw', isa => 'Net::RackSpace::CloudServers', required => 1 );
 has 'totalramsize' => ( is => 'rw', isa => 'Int', );
@@ -35,8 +34,7 @@ sub refresh {
     );
     my $response = $self->cloudservers->_request($request);
     return if $response->code == 204;
-    confess 'Unknown error ' . $response->code
-      unless scalar grep { $response->code eq $_ } ( 200, 203 );
+    confess 'Unknown error ' . $response->code unless ( $response->code ~~ [ 200, 203 ] );
     my $hr = from_json( $response->content );
     warn Dump($hr) if $DEBUG;
 
@@ -72,7 +70,7 @@ Net::RackSpace::CloudServers::Limits - a RackSpace CloudServers Limits instance
 
 =head1 VERSION
 
-version 0.12_02
+version 0.10
 
 =head1 SYNOPSIS
 
