@@ -1,7 +1,7 @@
 package Net::RackSpace::CloudServers::Server;
 
 BEGIN {
-    $Net::RackSpace::CloudServers::Server::VERSION = '0.12_02';
+    $Net::RackSpace::CloudServers::Server::VERSION = '0.10';
 }
 use warnings;
 use strict;
@@ -11,7 +11,6 @@ use HTTP::Request;
 use JSON;
 use YAML;
 use Net::RackSpace::CloudServers::Image;
-use Carp;
 
 has 'cloudservers' => ( is => 'rw', isa => 'Net::RackSpace::CloudServers', required => 1 );
 has 'id'       => ( is => 'ro', isa => 'Int',        required => 1, default => 0 );
@@ -175,7 +174,7 @@ Net::RackSpace::CloudServers::Server - a RackSpace CloudServers Server instance
 
 =head1 VERSION
 
-version 0.12_02
+version 0.10
 
 =head1 SYNOPSIS
 
